/**
 * Copyright (c) 2009-2012, Netbout.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are PROHIBITED without prior written permission from
 * the author. This product may NOT be used anywhere and on any computer
 * except the server platform of netBout Inc. located at www.netbout.com.
 * Federal copyright law prohibits unauthorized reproduction by any means
 * and imposes fines up to $25,000 for violation. If you received
 * this code accidentally and without intent to use it, please report this
 * incident to the author by email.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package com.netbout.notifiers.email;

import com.netbout.rest.BaseRs;
import com.netbout.rest.LoginRequiredException;
import com.netbout.spi.text.SecureString;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.core.Response;

/**
 * Shortcut for emails.
 *
 * @author Yegor Bugayenko (yegor@netbout.com)
 * @version $Id$
 */
@Path("/e")
public final class ShortcutRs extends BaseRs {

    /**
     * Front page of the shortcut.
     * @param hash The text of the anchor
     * @return The JAX-RS response
     */
    @GET
    @Path("/{hash}")
    public Response front(@PathParam("hash") final String hash) {
        AnchorEmail anchor;
        try {
            anchor = new AnchorEmail(hash, this.hub());
        } catch (BrokenAnchorException ex) {
            throw new LoginRequiredException(this, ex);
        }
        return Response.seeOther(
            this.base().path("/auth")
                .replaceQueryParam("identity", "{who}")
                .replaceQueryParam("secret", "{secret}")
                .replaceQueryParam("goto", "/{bout}")
                .build(
                    anchor.identity().name(),
                    new SecureString(anchor.identity().name()),
                    anchor.bout().number()
            )
        ).build();
    }

}
